==> create-fly-1.21.8-6.0.8-2-sources.jar: com/zurrtum/create/content/logistics/chute/SmartChuteBlock.java <==
package com.zurrtum.create.content.logistics.chute;

import com.zurrtum.create.AllBlockEntityTypes;
import net.minecraft.class_1750;
import net.minecraft.class_1922;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2591;
import net.minecraft.class_2680;
import net.minecraft.class_2689.class_2690;
import net.minecraft.class_2741;
import net.minecraft.class_2746;
import net.minecraft.class_3218;
import net.minecraft.class_5819;
import net.minecraft.class_9904;
import org.jetbrains.annotations.Nullable;

public class SmartChuteBlock extends AbstractChuteBlock {

    public SmartChuteBlock(class_2251 p_i48440_1_) {
        super(p_i48440_1_);
        method_9590(method_9564().method_11657(POWERED, true));
    }

    public static final class_2746 POWERED = class_2741.field_12484;

    @Override
    public void method_9612(
        class_2680 state,
        class_1937 level,
        class_2338 pos,
        class_2248 block,
        @Nullable class_9904 wireOrientation,
        boolean isMoving
    ) {
        super.method_9612(state, level, pos, block, wireOrientation, isMoving);
        if (level.field_9236)
            return;
        if (!level.method_8397().method_8677(pos, this))
            level.method_64310(pos, this, 1);
    }

    @Override
    public void method_9588(class_2680 state, class_3218 worldIn, class_2338 pos, class_5819 r) {
        boolean previouslyPowered = state.method_11654(POWERED);
        if (previouslyPowered != worldIn.method_49803(pos))
            worldIn.method_8652(pos, state.method_28493(POWERED), class_2248.field_31028);
    }

    @Override
    public class_2680 method_9605(class_1750 ctx) {
        return super.method_9605(ctx).method_11657(POWERED, ctx.method_8045().method_49803(ctx.method_8037()));
    }

    @Override
    public class_2591<? extends ChuteBlockEntity> getBlockEntityType() {
        return AllBlockEntityTypes.SMART_CHUTE;
    }

    @Override
    protected void method_9515(class_2690<class_2248, class_2680> builder) {
        super.method_9515(builder.method_11667(POWERED));
    }

    @Override
    public class_2680 updateChuteState(class_2680 state, class_2680 above, class_1922 world, class_2338 pos) {
        return state;
    }

}

==> create-fly-1.21.11-pre1-6.0.8-1-sources.jar: com/zurrtum/create/content/logistics/chute/SmartChuteBlock.java <==
package com.zurrtum.create.content.logistics.chute;

import com.zurrtum.create.AllBlockEntityTypes;
import net.minecraft.class_1750;
import net.minecraft.class_1922;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2591;
import net.minecraft.class_2680;
import net.minecraft.class_2689.class_2690;
import net.minecraft.class_2741;
import net.minecraft.class_2746;
import net.minecraft.class_3218;
import net.minecraft.class_5819;
import net.minecraft.class_9904;
import org.jetbrains.annotations.Nullable;

public class SmartChuteBlock extends AbstractChuteBlock {

    public SmartChuteBlock(class_2251 p_i48440_1_) {
        super(p_i48440_1_);
        method_9590(method_9564().method_11657(POWERED, true));
    }

    public static final class_2746 POWERED = class_2741.field_12484;

    @Override
    public void method_9612(class_2680 state, class_1937 level, class_2338 pos, class_2248 block, @Nullable class_9904 wireOrientation, boolean isMoving) {
        super.method_9612(state, level, pos, block, wireOrientation, isMoving);
        if (level.method_8608())
            return;
        if (!level.method_8397().method_8677(pos, this))
            level.method_64310(pos, this, 1);
    }

    @Override
    public void method_9588(class_2680 state, class_3218 worldIn, class_2338 pos, class_5819 r) {
        boolean previouslyPowered = state.method_11654(POWERED);
        if (previouslyPowered != worldIn.method_49803(pos))
            worldIn.method_8652(pos, state.method_28493(POWERED), class_2248.field_31028);
    }

    @Override
    public class_2680 method_9605(class_1750 ctx) {
        return super.method_9605(ctx).method_11657(POWERED, ctx.method_8045().method_49803(ctx.method_8037()));
    }

    @Override
    public class_2591<? extends ChuteBlockEntity> getBlockEntityType() {
        return AllBlockEntityTypes.SMART_CHUTE;
    }

    @Override
    protected void method_9515(class_2690<class_2248, class_2680> builder) {
        super.method_9515(builder.method_11667(POWERED));
    }

    @Override
    public class_2680 updateChuteState(class_2680 state, class_2680 above, class_1922 world, class_2338 pos) {
        return state;
    }

}
